// file: my_avr_defs.h
#pragma once

// C_ASSERT working for gcc (and .c files)
#define C_ASSERT(e) extern char __C_ASSERT__[(e)?1:-1] __attribute__((unused))

// AVR: friendly typedef for a fundamental data type
// policy:
//   use byte, int, char for normal programming, 
//   but uint16_t etc for network data access (int etc may be > 16 bits on some procs)
typedef unsigned char byte;
typedef unsigned int uint;

// note on tiny ints
// AVR can use tiny (signed 8bit) ints too (note this is not sanctioned by std C)
// to use:
// CFLAGS += -mint8
// __USING_MINT8 will be defined then
// 
// You should decide if your code can use tiny ints, consistently.

// the beloved min/max macros
#define min(X, Y)  ((X) < (Y) ? (X) : (Y))
#define max(X, Y)  ((X) > (Y) ? (X) : (Y))

// the macro to get the count of array elements for c-style static arrays
#define _countof(_Array) (sizeof(_Array) / sizeof(_Array[0]))
